==> dcmtk-docs-3.6.9-3-x86_64.pkg.tar.zst: usr/share/doc/dcmtk/html/search/groups_3.js <==
var searchData=
[
  ['class_20to_20create_20xml_20files_20using_20printf_20fprintf_20cout_20functions_0',['Helper class to create XML files using &quot;printf&quot;, &quot;fprintf&quot;, &quot;cout&quot;,... functions.',['../group__ToXMLStringTool.html',1,'']]],
  ['class_20to_20include_20binary_20data_20inside_20xml_20strings_20using_20base64_20encoding_1',['Helper class to include binary data inside XML strings using &quot;Base64 encoding&quot;.',['../group__XMLParserBase64Tool.html',1,'']]],
  ['concept_2',['SCP Thread Concept',['../group__SCPThread__Concept.html',1,'']]],
  ['conjunction_20with_20the_20update_20add_20functions_3',['Position helper functions (use in conjunction with the update&amp;add functions)',['../group__xmlPosition.html',1,'']]],
  ['construction_4',['Tools for in-place construction',['../group__OFin__place__helpers.html',1,'']]],
  ['cout_20functions_5',['Helper class to create XML files using &quot;printf&quot;, &quot;fprintf&quot;, &quot;cout&quot;,... functions.',['../group__ToXMLStringTool.html',1,'']]],
  ['create_20or_20update_20the_20xmlnode_20structure_6',['Create or Update the XMLNode structure',['../group__xmlModify.html',1,'']]],
  ['create_20xml_20files_20using_20printf_20fprintf_20cout_20functions_7',['Helper class to create XML files using &quot;printf&quot;, &quot;fprintf&quot;, &quot;cout&quot;,... functions.',['../group__ToXMLStringTool.html',1,'']]],
  ['creating_20from_20scratch_20a_20xmlnode_20structure_8',['Creating from scratch a XMLNode structure',['../group__creation.html',1,'']]]
];

==> dcmtk-docs-3.7.0-1-x86_64.pkg.tar.zst: usr/share/doc/dcmtk/html/search/groups_3.js <==
var searchData=
[
  ['class_20to_20create_20xml_20files_20using_20printf_20fprintf_20cout_20functions_0',['Helper class to create XML files using &quot;printf&quot;, &quot;fprintf&quot;, &quot;cout&quot;,... functions.',['../group__ToXMLStringTool.html',1,'']]],
  ['class_20to_20include_20binary_20data_20inside_20xml_20strings_20using_20base64_20encoding_1',['Helper class to include binary data inside XML strings using &quot;Base64 encoding&quot;.',['../group__XMLParserBase64Tool.html',1,'']]],
  ['concept_2',['SCP Thread Concept',['../group__SCPThread__Concept.html',1,'']]],
  ['conjunction_20with_20the_20update_20add_20functions_3',['Position helper functions (use in conjunction with the update&amp;amp;add functions)',['../group__xmlPosition.html',1,'']]],
  ['construction_4',['Tools for in-place construction',['../group__OFin__place__helpers.html',1,'']]],
  ['cout_20functions_5',['Helper class to create XML files using &quot;printf&quot;, &quot;fprintf&quot;, &quot;cout&quot;,... functions.',['../group__ToXMLStringTool.html',1,'']]],
  ['create_20or_20update_20the_20xmlnode_20structure_6',['Create or Update the XMLNode structure',['../group__xmlModify.html',1,'']]],
  ['create_20xml_20files_20using_20printf_20fprintf_20cout_20functions_7',['Helper class to create XML files using &quot;printf&quot;, &quot;fprintf&quot;, &quot;cout&quot;,... functions.',['../group__ToXMLStringTool.html',1,'']]],
  ['creating_20from_20scratch_20a_20xmlnode_20structure_8',['Creating from scratch a XMLNode structure',['../group__creation.html',1,'']]]
];
